from setuptools import setup

setup(
    name='calculator_metatron',
    version='1.0.1',
    description='Simple calculator with python',
    url='',
    author='Rômulo do Carmo Sousa',
    author_email='romulocarmos@gmail.com',
    license='MIT',
    packages=['calc'],
    zip_safe=False
)